@@ -231,6 +231,8 @@ public:
 	void process(float **ins, float **outs, uint32_t nframes);
 
 	virtual void updatePreset(bool bDirty) = 0;
+	virtual void updateParam(ParamIndex index) = 0;
+	virtual void updateParams() = 0;
 
 	void midiInEnabled(bool on);
 	uint32_t midiInCount();
