@@ -1,7 +1,7 @@
 // synthv1widget_env.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ class synthv1widget_env : public QFrame
 public:
 
 	// Constructor.
-	synthv1widget_env(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	synthv1widget_env(QWidget *pParent = nullptr);
 	// Destructor.
 	~synthv1widget_env();
 
